@@ -124,12 +124,12 @@ def radcal(ras, save=False, quiet=True, debug=False):
     #################
     # Photon Energy #
     #################
-    #Lambda is in nm. 1e7 ergs = 1 Joule
+    #Lambda is in A. 1e7 ergs = 1 Joule
     h=6.62607004e-34
     c=3e8
-    eFUV1=1e7*h*c/(FUV1*10e-10)
-    eFUV2=1e7*h*c/(FUV2*10e-10)
-    eNUV=1e7*h*c/(NUV*10e-10)
+    eFUV1=1e7*h*c/(FUV1*1e-9)
+    eFUV2=1e7*h*c/(FUV2*1e-9)
+    eNUV=1e7*h*c/(NUV*1e-9)
 
     ##################
     # Effective Area #
@@ -258,7 +258,7 @@ def radcal(ras, save=False, quiet=True, debug=False):
             rasfits=ras[k]
 
         hdr0=dc(rasfits[0].header)
-        hdr0['HISTORY']='Mgii, SiIV and CII radiometric calibration performed on '+dt.datetime.now().strftime("%Y-%m-%d")
+        hdr0['HISTORY']='NUV and FUV radiometric calibration performed on '+dt.datetime.now().strftime("%Y-%m-%d")
         hdr0['HISTORY']='FITS made with astropy on '+dt.datetime.now().strftime("%Y-%m-%d")
         hdr0['BUNIT']="erg s^-1 cm^-2 angstrom^-1 sr^-1"
         dat={}
